@@ -120,11 +120,11 @@ class FeedManager(gobject.GObject):
             callback(*args)
             gtk.gdk.threads_leave()
 
-    def add_feed(self, url, sync, callback, data=None):
+    def add_feed(self, url, sync, save, callback, data=None):
 
         # Create a new thread to update from network
         adding_thread = Thread(target=self._add_feed_in_thread,
-                               args=(url, sync, callback, data))
+                               args=(url, sync, save, callback, data))
         adding_thread.start()
 
     def update_feed(self, feed, callback, data=None):
@@ -412,7 +412,7 @@ class FeedManager(gobject.GObject):
 
         self._safe_callback(callback, urls, user_data)
 
-    def save(self, callback, data=None):
+    def save(self, callback=None, data=None):
         # TODO: migrate to "with" statement when available
         try:
             db_file = open(constants.RSS_DB_FILE, 'w')
@@ -624,7 +624,7 @@ class FeedManager(gobject.GObject):
 
         self._safe_callback(callback, True, data)
 
-    def _add_feed_in_thread(self, url, sync, callback, user_data):
+    def _add_feed_in_thread(self, url, sync, save, callback, user_data):
 
         parsed_url = urlparse.urlsplit(url)
         if parsed_url.scheme == '':
@@ -640,8 +640,10 @@ class FeedManager(gobject.GObject):
 
         new_feed_data = ReSiStanceFeedDict(feedparser.parse(url), sync)
 
-        # 200 == OK, and 3xx are redirections
-        if new_feed_data.status!=200 and new_feed_data.status/100 != 3:
+        # 200 == OK, and 3xx are redirections.
+        # On the other hand bozo==1 if there was some problem parsing the feed
+        if (new_feed_data.status!=200 and new_feed_data.status/100 != 3) or \
+                new_feed_data.bozo:
             self._safe_callback(callback, None, None, user_data)
             return
 
@@ -656,10 +658,11 @@ class FeedManager(gobject.GObject):
         self._safe_callback(callback, pixbuf, new_feed_data, user_data)
 
         # Save to disk
-        try:
-            self.save(None)
-        except IOError:
-            pass
+        if save:
+            try:
+                self.save(None)
+            except IOError:
+                pass
 
     def _update_feeds_in_thread(self, feed_data_list, callback, user_data):
 
