@@ -691,8 +691,8 @@ class FeedsWindow(hildon.StackableWindow):
             path = self.view.get_model().get_path(feed_iter)
             row_reference = gtk.TreeRowReference(self.view.get_model(), path)
 
-            # Add feed to manager
-            self.manager.add_feed(url, False, self._feed_added_cb, row_reference)
+            # Add feed to manager. Do not sync with Google and save the feed on disk
+            self.manager.add_feed(url, False, True, self._feed_added_cb, row_reference)
 
             dialog.destroy()
 
@@ -733,10 +733,6 @@ class FeedsWindow(hildon.StackableWindow):
                   self.FEEDS_MODEL_SYNC_COLUMN, new_feed_data.sync,
                   self.FEEDS_MODEL_ID_COLUMN, hash(new_feed_data.href))
 
-        # Take screenshot
-        hildon.hildon_gtk_window_take_screenshot(self, False)
-        hildon.hildon_gtk_window_take_screenshot(self, True)
-
     def _multiple_add_cb(self, pixbuf, new_feed_data, (num_operations, callback, data, row_reference), static = {"count" : 0}):
         ''' Simulating a static variable with a default argument hack '''
         self._feed_added_cb(pixbuf, new_feed_data, row_reference, stop_progress=False)
@@ -750,7 +746,7 @@ class FeedsWindow(hildon.StackableWindow):
         else:
             hildon.hildon_gtk_window_set_progress_indicator(self, True)
 
-    def _add_multiple_feeds(self, urls, sync=False, callback=None, data=None):
+    def _add_multiple_feeds(self, urls, sync=False, save=False, callback=None, data=None):
         # Quickly show feedback to user
         hildon.hildon_gtk_window_set_progress_indicator(self, True)
         for url in urls:
@@ -760,7 +756,7 @@ class FeedsWindow(hildon.StackableWindow):
             row_reference = gtk.TreeRowReference(self.view.get_model(), path)
 
             # Add feed to manager
-            self.manager.add_feed(url, sync, self._multiple_add_cb,
+            self.manager.add_feed(url, sync, save, self._multiple_add_cb,
                                   (len(urls), callback, data, row_reference))
 
     def _sync_google_reader_read_status_cb(self, synced, user_data):
@@ -781,6 +777,11 @@ class FeedsWindow(hildon.StackableWindow):
     def _all_synchronized_feeds_added_cb(self, user_data):
         ''' Called after adding all the feeds retrieved from Google Reader '''
 
+        # Do not update read/unread status if all the feeds failed to sync
+        synced_feeds = [feed for feed in self.manager.get_feed_list() if feed.sync]
+        if len(synced_feeds) == 0:
+            return
+
         # Update read/unread status
         hildon.hildon_banner_show_information(self, '', _('Synchronizing read/unread status with Google Reader'))
         hildon.hildon_gtk_window_set_progress_indicator(self, True)
@@ -813,7 +814,7 @@ class FeedsWindow(hildon.StackableWindow):
 
         if urls:
             # Add feeds to UI asynchronously
-            self._add_multiple_feeds(urls, True, self._all_synchronized_feeds_added_cb)
+            self._add_multiple_feeds(urls, sync=True, callback=self._all_synchronized_feeds_added_cb)
 
     def _preferences_response_cb(self, dialog, response):
 
@@ -952,9 +953,12 @@ class FeedsWindow(hildon.StackableWindow):
             # Disable canceling
             dialog.connect('delete-event', lambda widget,event : True)
 
+    def _save_feeds_after_multiple_add(self, data=None):
+        self.manager.save()
+
     def _find_window_urls_found_cb(self, find_window, urls):
         if len(urls):
-            self._add_multiple_feeds(urls)
+            self._add_multiple_feeds(urls, callback=self._save_feeds_after_multiple_add)
 
     def _found_cb(self, key_words, dialog, feeds_info):
         if feeds_info == None:
@@ -1038,7 +1042,7 @@ class FeedsWindow(hildon.StackableWindow):
             return
 
         hildon.hildon_gtk_window_set_progress_indicator(self, True)
-        self._add_multiple_feeds(feed_url_list)
+        self._add_multiple_feeds(feed_url_list, callback=self._save_feeds_after_multiple_add)
 
     def _find_feed_cb(self, button):
         dialog = FindFeedsDialog(self)
